# Generated by Django 5.2.3 on 2025-11-14 08:44

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("marinerg_data_access", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="dataset",
            name="id_authority",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="dataset",
            name="keyword_vocabularies",
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="dataset",
            name="keywords",
            field=models.CharField(blank=True, max_length=250),
        ),
        migrations.AddField(
            model_name="dataset",
            name="license",
            field=models.CharField(max_length=250, null=True),
        ),
        migrations.AddField(
            model_name="dataset",
            name="parent",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="children",
                to="marinerg_data_access.dataset",
            ),
        ),
    ]
