# Generated by Django 5.2.3 on 2025-11-14 08:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "marinerg_data_access",
            "0002_dataset_id_authority_dataset_keyword_vocabularies_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="dataset",
            name="keyword_vocabularies",
        ),
        migrations.RemoveField(
            model_name="dataset",
            name="keywords",
        ),
    ]
