# Generated by Django 5.2.3 on 2025-11-14 09:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("marinerg_data_access", "0003_remove_dataset_keyword_vocabularies_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="DatasetTag",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("value", models.CharField(max_length=200)),
            ],
        ),
        migrations.AddField(
            model_name="dataset",
            name="tags",
            field=models.ManyToManyField(
                blank=True,
                related_name="datasets",
                to="marinerg_data_access.datasettag",
            ),
        ),
    ]
